pub enum Line<'line> {
Space,
Zone(Zone<'line>),
Continuation(ZoneInfo<'line>),
Rule(Rule<'line>),
Link(Link<'line>),
}Expand description
A type of valid line that has been parsed.
Variants
Space
This line is empty.
Zone(Zone<'line>)
This line contains a zone definition.
Continuation(ZoneInfo<'line>)
This line contains a continuation of a zone definition.
Rule(Rule<'line>)
This line contains a rule definition.
Link(Link<'line>)
This line contains a link definition.
Implementations