Saving

Enum Saving 

pub enum Saving<'line> {
    NoSaving,
    OneOff(TimeSpec),
    Multiple(&'line str),
}
The amount of daylight saving time (DST) to apply to this timespan. This is a special type for a certain field in a zone line, which can hold different types of value.

Variants



NoSaving

Just stick to the base offset.



OneOff(TimeSpec)

This amount of time should be saved while this timespan is in effect. (This is the equivalent to there being a single one-off rule with the given amount of time to save).



Multiple(&'line str)

All rules with the given name should apply while this timespan is in effect.