pub enum YearSpec {
Minimum,
Maximum,
Number(i64),
}Expand description
A year definition field.
A year has one of the following representations in a file:
minorminimum, the minimum year possible, for when a rule needs to apply up until the first rule with a specific year;maxormaximum, the maximum year possible, for when a rule needs to apply after the last rule with a specific year;- a year number, referring to a specific year.
Variants
Minimum
The minimum year possible: min or minimum.
Maximum
The maximum year possible: max or maximum.
Number(i64)
A specific year number.